// wait until the html page is loaded before execution
//$(document).ready(function() {
    // this will execute when the document is ready
//});

// call this function when the document is ready
// this is the same as above
$(function() {
    // anything I write in here, WON'T be executed until the page
    // is fully loaded
    
    // creating a handler for click events
    // on the "ADD TASK" button
    $('#add').click(function(evt){
        // don't actually submit the form
        evt.preventDefault();
        
        // got the form values
        var desc = $('#description').val();
        var due = $('#due').val();
        var priority = $('#priority').val();
        
        // check if description is empty
        if(desc === "") {
            alert("You have an empty description!");
            return;
        }
        
        // check if date is valid
        // date is empty
        // or the value of date is NaN (invalid date)
        if(due === "" || isNaN((new Date(due)).valueOf()) ) {
            alert("You have an invalid due date!");
            return;
        }
        
        // at this point we can add the to do item
        
        var todo = {
            desc: desc,
            due: new Date(due),
            priority: priority
        };
        
        // send the AJAX request to the server to save
        // the todo item
        var request = $.ajax({
            type: "POST",
            url: "server.php",
            cache: false,
            dataType: "json",
            data: {
                cmd: "store",
                data: JSON.stringify(todo)
            }
        });
        
        // register a callback for when the promise is
        // fulfilled
        request.done(function(data){
            if(data.error) {
                // we had an error on the server
                alert("Something went wrong on the server." +
                      " The todo item was not stored.");
            } else {
                // we stored the todo item on the sever
                // now let's add it to the DOM
                if($("#todo table").length === 0) {
                    // there is no table yet because the array
                    // returned was empty
                    
                    // so...let's create a table
                    $("#todo").append(
                        '<table class="table" id="todo-table">' +
                          '<thead>' +
                            '<tr><th>Descrtiption</th><th>Priority</th>'+
                            '<th>Due</th><th></th></tr>'+
                          '</thead>' +
                          '<tbody id="todo-body"></tbody>' +
                        '</table>'
                    );
                }
                
                // add in the event
                $('#todo-body').append(
                    '<tr id="'+ data.id +'"><td>' + desc +
                    '</td><td>' + priority +
                    '</td><td class="todo-date">' + due +
                    '</td><td>'+
                    '<span class="glyphicon glyphicon-remove todo-remove"></span></td></tr>'
                );
            }
        });
        
        
        
    }); // Click event handler for the form
    
    // create event listener to deal with deletions
    $("#todo").on("click", "table .todo-remove", function(evt){
        // user clicked on a delete button
        evt.preventDefault();
        
        // gets back a jQuery object representing the DOM
        // element that was clicked
        $(evt.target).parents("tr").remove();
        
        // is the table empty?
        if($('#todo-body tr').length === 0) {
            // there are no tables rows left
            $('#todo table').remove();
        }
    });
    
    // function to check if items are overdue!
    setInterval(function(){
        var dueDates = $('.todo-date');
        $.each(dueDates, function(index, element){
            // for each date in dueDates
            var date = new Date($(element).text());
            
            // get current date
            var curr = new Date();
            
            if(date < curr) {
                $(element).parents("tr").addClass("red");
            }
        });
    }, 1000);
});